agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# inmydata agents API reference

The inmydata agents Python Library enables you to build AI agents that can rapidly access data from the inmydata platform. Documentation, quickstarts, and examples can be found here

To install:

    pip install inmydata

Classes:

- AIDataFilter
- AIDataSimpleFilter
- AIQuestionOutputTypeEnum
- AITypeEnum
- Answer
- CalendarAssistant
- ConditionOperator
- ConversationalData
- FinancialPeriodDetails
- LogicalOperator
- Model
- QuestionResponse
- StructuredDataDriver